@@ -1,9 +1,9 @@
 local path = require 'pl.path'
 local normpath = path.normpath
+local defaultOutput = 'default_output_handler'
 
 describe('Tests command-line interface', function()
   it('default options', function()
-    local defaultOutput = 'default_output_handler'
     local lpath = './src/?.lua;./src/?/?.lua;./src/?/init.lua'
     local cpath = path.is_windows and './csrc/?.dll;./csrc/?/?.dll;' or './csrc/?.so;./csrc/?/?.so;'
     local cli = require 'busted.modules.cli'({ standalone = false, output = defaultOutput })
@@ -38,6 +38,7 @@ describe('Tests command-line interface', function()
     assert.is_false(args['defer-print'])
     assert.is_nil(args.f)
     assert.is_nil(args['config-file'])
+    assert.is_nil(args['coverage-config-file'])
     assert.is_nil(args.shuffle)
     assert.is_nil(args['shuffle-files'])
     assert.is_nil(args['shuffle-tests'])
@@ -362,6 +363,7 @@ describe('Tests using .busted tasks', function()
     assert.is_false(args['defer-print'])
     assert.is_nil(args.f)
     assert.is_nil(args['config-file'])
+    assert.is_nil(args['coverage-config-file'])
     assert.is_nil(args.shuffle)
     assert.is_nil(args['shuffle-files'])
     assert.is_nil(args['shuffle-tests'])
@@ -421,6 +423,7 @@ describe('Tests using .busted tasks', function()
     assert.is_false(args['enable-sound'])
     assert.is_false(args['suppress-pending'])
     assert.is_false(args['defer-print'])
+    assert.is_nil(args['coverage-config-file'])
     assert.is_nil(args.shuffle)
     assert.is_nil(args['shuffle-files'])
     assert.is_nil(args['shuffle-tests'])
